<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <title>{{ title }}</title>
	<script src="static/island_backup.js"></script>
	<link rel="stylesheet" type="text/css" href="static/island_backup.css">
</head>

<body>
{% for data in all_blocks %}
    <div class="thread" id="{{ data.id }}">
        <div class="image-box">
                <img src="{{ data.image }}" onclick="show_big(this)" data-big=0>
        </div>
        <div class="right-content">
            <p><span>{{ data.created_time}}</span> <span>ID: {{ data.uid }}</span> <span>No.{{ data.id }}</span></p>
            <p>{{ data.content }}</p>
        </div>
    </div>
{% endfor %}

{% if page_obj %}
    <div class="page">
        {% include 'pages.html' %}
    </div>
{% endif %}

</body>
</html>