html, body{
    height: 100%;
    background-color: #ffe;
    font-size: 16px;
    color: #800000;
}

.thread {
    display: table;
    height: auto;
    padding: 10px 15px 10px 15px;
    box-sizing: border-box;
    width: 100%;
}

.page {
    padding: 5px 15px;
}
img {
    float: left;
    height: auto;
    max-width: 25%;
    display: block;
    cursor: zoom-in;
}

.right-content {
    float: left;
    height: 100%;
    width: 70%;
    background-color: #f0e0d6;
    padding: 10px 15px 10px 15px;
    margin-left: 15px;
    box-shadow: 1px 1px 3px #888888;
    border-radius: 5px;
}

p {
    margin-bottom: 10px;
    font-size: 16px;
}

span {
    font-size: 14px;
}

.button {
    background-color: #4CAF50; /* Green */
    border: none;
    color: white;
    padding: 10px 32px;
    text-align: center;
    text-decoration: none;
    display: inline-block;
    font-size: 16px;
    margin: 4px 0;
    cursor: pointer;
    -webkit-transition-duration: 0.4s; /* Safari */
    transition-duration: 0.4s;
}
.button:hover {
    box-shadow: 0 12px 16px 0 rgba(0,0,0,0.24),0 17px 50px 0 rgba(0,0,0,0.19);
}
.to_right {
    float: right;
}

.reply-color {
    color: #789922;
    font-size: 16px;
}
